# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.1.0-1-ga85a9c1
https://git.km3net.de/common/km3net-dataformat
"""

# trigger
data = dict(
    JTRIGGER3DSHOWER=1,
    JTRIGGERMXSHOWER=2,
    JTRIGGER3DMUON=4,
    JTRIGGERNB=5,
    FACTORY_LIMIT=31,
)
